Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--source/blender/blenlib/intern/bpath.c2
-rw-r--r--source/blender/blenlib/intern/graph.c2
-rw-r--r--source/blender/blenlib/intern/math_geom.c2
-rw-r--r--source/blender/blenlib/intern/path_util.c2
-rw-r--r--source/blender/blenloader/BLO_sys_types.h2
-rw-r--r--source/blender/editors/animation/anim_markers.c2
-rw-r--r--source/blender/editors/animation/keyframes_general.c2
-rw-r--r--source/blender/editors/animation/keyframing.c2
-rw-r--r--source/blender/editors/animation/keyingsets.c2
-rw-r--r--source/blender/editors/armature/editarmature.c6
-rw-r--r--source/blender/editors/armature/meshlaplacian.c2
-rw-r--r--source/blender/editors/armature/poseSlide.c8
-rw-r--r--source/blender/editors/armature/poselib.c2
-rw-r--r--source/blender/editors/curve/editcurve.c2
-rw-r--r--source/blender/editors/interface/interface.c6
-rw-r--r--source/blender/editors/interface/interface_handlers.c4
-rw-r--r--source/blender/editors/interface/interface_regions.c6
-rw-r--r--source/blender/editors/interface/view2d.c2
-rw-r--r--source/blender/editors/mesh/editmesh_bvh.c2
-rw-r--r--source/blender/editors/object/object_constraint.c2
-rw-r--r--source/blender/editors/physics/dynamicpaint_ops.c2
-rw-r--r--source/blender/editors/screen/screen_edit.c2
-rw-r--r--source/blender/editors/sculpt_paint/paint_image.c8
-rw-r--r--source/blender/editors/sculpt_paint/sculpt.c2
-rw-r--r--source/blender/editors/space_action/space_action.c2
-rw-r--r--source/blender/editors/space_clip/clip_draw.c4
-rw-r--r--source/blender/editors/space_clip/space_clip.c2
-rw-r--r--source/blender/editors/space_clip/tracking_ops.c6
-rw-r--r--source/blender/editors/space_console/space_console.c2
-rw-r--r--source/blender/editors/space_graph/space_graph.c2
-rw-r--r--source/blender/editors/space_text/text_draw.c4
-rw-r--r--source/blender/editors/space_view3d/drawobject.c4
-rw-r--r--source/blender/editors/transform/transform_constraints.c2
-rw-r--r--source/blender/editors/transform/transform_conversions.c48
-rw-r--r--source/blender/editors/transform/transform_generics.c2
-rw-r--r--source/blender/makesdna/DNA_customdata_types.h2
-rw-r--r--source/blender/makesdna/DNA_userdef_types.h2
-rw-r--r--source/blender/makesrna/intern/rna_tracking.c4
-rw-r--r--source/blender/makesrna/intern/rna_wm_api.c2
-rw-r--r--source/blender/modifiers/intern/MOD_mirror.c2
-rw-r--r--source/blender/python/intern/bpy_rna.c2
-rw-r--r--source/blender/windowmanager/WM_types.h2
-rw-r--r--source/blender/windowmanager/intern/wm_event_system.c4
-rw-r--r--source/blender/windowmanager/intern/wm_operators.c2
-rw-r--r--source/creator/creator.c2
45 files changed, 88 insertions, 88 deletions
diff --git a/source/blender/blenlib/intern/bpath.c b/source/blender/blenlib/intern/bpath.c
index 7bc2446b64b..6436afe85aa 100644
--- a/source/blender/blenlib/intern/bpath.c
+++ b/source/blender/blenlib/intern/bpath.c
@@ -609,7 +609,7 @@ int bpath_relocate_visitor(void *pathbase_v, char *path_dst, const char *path_sr
}
/* Make referenced file absolute. This would be a side-effect of
- * BLI_cleanup_file, but we do it explicitely so we know if it changed. */
+ * BLI_cleanup_file, but we do it explicitly so we know if it changed. */
BLI_strncpy(filepath, path_src, FILE_MAX);
if (BLI_path_abs(filepath, base_old)) {
/* Path was relative and is now absolute. Remap.
diff --git a/source/blender/blenlib/intern/graph.c b/source/blender/blenlib/intern/graph.c
index d0d3d0e137e..967c4411903 100644
--- a/source/blender/blenlib/intern/graph.c
+++ b/source/blender/blenlib/intern/graph.c
@@ -895,7 +895,7 @@ static void markdownSecondarySymmetry(BGraph *graph, BNode *node, int depth, int
int i;
/* count the number of branches in this symmetry group
- * and determinte the axis of symmetry
+ * and determinate the axis of symmetry
* */
for (i = 0; i < node->degree; i++)
{
diff --git a/source/blender/blenlib/intern/math_geom.c b/source/blender/blenlib/intern/math_geom.c
index 405db864598..2918461540d 100644
--- a/source/blender/blenlib/intern/math_geom.c
+++ b/source/blender/blenlib/intern/math_geom.c
@@ -1524,7 +1524,7 @@ static int point_in_slice(const float p[3], const float v1[3], const float l1[3]
* what is a slice ?
* some maths:
* a line including l1,l2 and a point not on the line
- * define a subset of R3 delimeted by planes parallel to the line and orthogonal
+ * define a subset of R3 delimited by planes parallel to the line and orthogonal
* to the (point --> line) distance vector,one plane on the line one on the point,
* the room inside usually is rather small compared to R3 though still infinte
* useful for restricting (speeding up) searches
diff --git a/source/blender/blenlib/intern/path_util.c b/source/blender/blenlib/intern/path_util.c
index ffee44078b2..f2c11f46cd6 100644
--- a/source/blender/blenlib/intern/path_util.c
+++ b/source/blender/blenlib/intern/path_util.c
@@ -264,7 +264,7 @@ int BLI_uniquename_cb(int (*unique_check)(void *, const char *), void *arg, cons
* name_offs: should be calculated using offsetof(structname, membername) macro from stddef.h
* len: maximum length of string (to prevent overflows, etc.)
* defname: the name that should be used by default if none is specified already
- * delim: the character which acts as a delimeter between parts of the name
+ * delim: the character which acts as a delimiter between parts of the name
*/
static int uniquename_find_dupe(ListBase *list, void *vlink, const char *name, short name_offs)
{
diff --git a/source/blender/blenloader/BLO_sys_types.h b/source/blender/blenloader/BLO_sys_types.h
index 9430878a641..7dbd4df1056 100644
--- a/source/blender/blenloader/BLO_sys_types.h
+++ b/source/blender/blenloader/BLO_sys_types.h
@@ -49,7 +49,7 @@ extern "C" {
#if defined(_WIN32) && !defined(FREE_WINDOWS)
-/* The __intXX are built-in types of the visual complier! So we don't
+/* The __intXX are built-in types of the visual compiler! So we don't
* need to include anything else here. */
diff --git a/source/blender/editors/animation/anim_markers.c b/source/blender/editors/animation/anim_markers.c
index b3efeffe1d9..803516e211b 100644
--- a/source/blender/editors/animation/anim_markers.c
+++ b/source/blender/editors/animation/anim_markers.c
@@ -751,7 +751,7 @@ static int ed_marker_move_modal(bContext *C, wmOperator *op, wmEvent *evt)
return OPERATOR_CANCELLED;
case RIGHTMOUSE:
- /* press = user manually demands transform to be cancelled */
+ /* press = user manually demands transform to be canceled */
if (evt->val == KM_PRESS) {
ed_marker_move_cancel(C, op);
return OPERATOR_CANCELLED;
diff --git a/source/blender/editors/animation/keyframes_general.c b/source/blender/editors/animation/keyframes_general.c
index 732f84bb33d..2067de22467 100644
--- a/source/blender/editors/animation/keyframes_general.c
+++ b/source/blender/editors/animation/keyframes_general.c
@@ -544,7 +544,7 @@ short copy_animedit_keys (bAnimContext *ac, ListBase *anim_data)
/* add to buffer */
newbuf= MEM_callocN(sizeof(BezTriple)*(aci->totvert+1), "copybuf beztriple");
- /* assume that since we are just resizing the array, just copy all existing data across */
+ /* assume that since we are just re-sizing the array, just copy all existing data across */
if (aci->bezt)
memcpy(newbuf, aci->bezt, sizeof(BezTriple)*(aci->totvert));
diff --git a/source/blender/editors/animation/keyframing.c b/source/blender/editors/animation/keyframing.c
index 2a66a6c0aba..559f6ad98d9 100644
--- a/source/blender/editors/animation/keyframing.c
+++ b/source/blender/editors/animation/keyframing.c
@@ -1193,7 +1193,7 @@ static int insert_key_menu_invoke (bContext *C, wmOperator *op, wmEvent *UNUSED(
/* if prompting or no active Keying Set, show the menu */
if ((scene->active_keyingset == 0) || RNA_boolean_get(op->ptr, "always_prompt")) {
- /* call the menu, which will call this operator again, hence the cancelled */
+ /* call the menu, which will call this operator again, hence the canceled */
ANIM_keying_sets_menu_setup(C, op->type->name, "ANIM_OT_keyframe_insert_menu");
return OPERATOR_CANCELLED;
}
diff --git a/source/blender/editors/animation/keyingsets.c b/source/blender/editors/animation/keyingsets.c
index 5d440bae2bc..abd57e35586 100644
--- a/source/blender/editors/animation/keyingsets.c
+++ b/source/blender/editors/animation/keyingsets.c
@@ -468,7 +468,7 @@ void ANIM_OT_keyingset_button_remove (wmOperatorType *ot)
static int keyingset_active_menu_invoke (bContext *C, wmOperator *op, wmEvent *UNUSED(event))
{
- /* call the menu, which will call this operator again, hence the cancelled */
+ /* call the menu, which will call this operator again, hence the canceled */
ANIM_keying_sets_menu_setup(C, op->type->name, "ANIM_OT_keying_set_active_set");
return OPERATOR_CANCELLED;
}
diff --git a/source/blender/editors/armature/editarmature.c b/source/blender/editors/armature/editarmature.c
index 365eb28278d..3c5de538fdc 100644
--- a/source/blender/editors/armature/editarmature.c
+++ b/source/blender/editors/armature/editarmature.c
@@ -3811,7 +3811,7 @@ static int armature_parent_set_exec(bContext *C, wmOperator *op)
* - the context iterator contains both selected bones and their mirrored copies,
* so we assume that unselected bones are mirrored copies of some selected bone
* - since the active one (and/or its mirror) will also be selected, we also need
- * to check that we are not trying to opearate on them, since such an operation
+ * to check that we are not trying to operate on them, since such an operation
* would cause errors
*/
@@ -4158,7 +4158,7 @@ static void bone_align_to_bone(ListBase *edbo, EditBone *selbone, EditBone *actb
/* if the bone being aligned has connected descendants they must be moved
* according to their parent new position, otherwise they would be left
- * in an unconsistent state: connected but away from the parent*/
+ * in an inconsistent state: connected but away from the parent*/
fix_editbone_connected_children(edbo, selbone);
return;
}
@@ -4207,7 +4207,7 @@ static int armature_align_bones_exec(bContext *C, wmOperator *op)
* - the context iterator contains both selected bones and their mirrored copies,
* so we assume that unselected bones are mirrored copies of some selected bone
* - since the active one (and/or its mirror) will also be selected, we also need
- * to check that we are not trying to opearate on them, since such an operation
+ * to check that we are not trying to operate on them, since such an operation
* would cause errors
*/
diff --git a/source/blender/editors/armature/meshlaplacian.c b/source/blender/editors/armature/meshlaplacian.c
index 74c44ea1f0d..eb707119263 100644
--- a/source/blender/editors/armature/meshlaplacian.c
+++ b/source/blender/editors/armature/meshlaplacian.c
@@ -832,7 +832,7 @@ void heat_bone_weighting(Object *ob, Mesh *me, float (*verts)[3], int numsource,
/* investigate:
* - transpose R in orthogonal
* - flipped normals and per face adding
- * - move cancelling to transform, make origco pointer
+ * - move canceling to transform, make origco pointer
*/
static LaplacianSystem *RigidDeformSystem = NULL;
diff --git a/source/blender/editors/armature/poseSlide.c b/source/blender/editors/armature/poseSlide.c
index f160e74ea03..adabf7405d6 100644
--- a/source/blender/editors/armature/poseSlide.c
+++ b/source/blender/editors/armature/poseSlide.c
@@ -239,7 +239,7 @@ static void pose_slide_apply_val (tPoseSlideOp *pso, FCurve *fcu, float *val)
switch (pso->mode) {
case POSESLIDE_PUSH: /* make the current pose more pronounced */
{
- /* perform a weighted average here, favouring the middle pose
+ /* perform a weighted average here, favoring the middle pose
* - numerator should be larger than denominator to 'expand' the result
* - perform this weighting a number of times given by the percentage...
*/
@@ -253,7 +253,7 @@ static void pose_slide_apply_val (tPoseSlideOp *pso, FCurve *fcu, float *val)
case POSESLIDE_RELAX: /* make the current pose more like its surrounding ones */
{
- /* perform a weighted average here, favouring the middle pose
+ /* perform a weighted average here, favoring the middle pose
* - numerator should be smaller than denominator to 'relax' the result
* - perform this weighting a number of times given by the percentage...
*/
@@ -660,14 +660,14 @@ static int pose_slide_modal (bContext *C, wmOperator *op, wmEvent *evt)
/* clean up temp data */
pose_slide_exit(op);
- /* cancelled! */
+ /* canceled! */
return OPERATOR_CANCELLED;
}
case MOUSEMOVE: /* calculate new position */
{
/* calculate percentage based on position of mouse (we only use x-axis for now.
- * since this is more conveninent for users to do), and store new percentage value
+ * since this is more convenient for users to do), and store new percentage value
*/
pso->percentage= (evt->x - pso->ar->winrct.xmin) / ((float)pso->ar->winx);
RNA_float_set(op->ptr, "percentage", pso->percentage);
diff --git a/source/blender/editors/armature/poselib.c b/source/blender/editors/armature/poselib.c
index cd3017c0e0f..ef01b895f38 100644
--- a/source/blender/editors/armature/poselib.c
+++ b/source/blender/editors/armature/poselib.c
@@ -1473,7 +1473,7 @@ static void poselib_preview_cleanup (bContext *C, wmOperator *op)
/* this signal does one recalc on pose, then unlocks, so ESC or edit will work */
pose->flag |= POSE_DO_UNLOCK;
- /* clear pose if cancelled */
+ /* clear pose if canceled */
if (pld->state == PL_PREVIEW_CANCEL) {
poselib_backup_restore(pld);
diff --git a/source/blender/editors/curve/editcurve.c b/source/blender/editors/curve/editcurve.c
index def93798067..56f20a14d13 100644
--- a/source/blender/editors/curve/editcurve.c
+++ b/source/blender/editors/curve/editcurve.c
@@ -2958,7 +2958,7 @@ static void subdividenurb(Object *obedit, int number_cuts)
*
* is an invariant for a single NURB curve. Raising the degree
* of the NURB is done elsewhere; the degree is assumed
- * constant during this opration. Degree is a property shared
+ * constant during this operation. Degree is a property shared
* by all controlpoints in a curve (even though it is stored
* per control point - this can be misleading).
* Adding a knot is done by searching for the place in the
diff --git a/source/blender/editors/interface/interface.c b/source/blender/editors/interface/interface.c
index 7e4ca0212fb..edddd9bf407 100644
--- a/source/blender/editors/interface/interface.c
+++ b/source/blender/editors/interface/interface.c
@@ -669,7 +669,7 @@ static int ui_but_update_from_old_block(const bContext *C, uiBlock *block, uiBut
return found;
}
-/* needed for temporarily rename buttons, such as in outliner or fileselect,
+/* needed for temporarily rename buttons, such as in outliner or file-select,
* they should keep calling uiDefButs to keep them alive */
/* returns 0 when button removed */
int uiButActiveOnly(const bContext *C, uiBlock *block, uiBut *but)
@@ -764,7 +764,7 @@ static void ui_menu_block_set_keyaccels(uiBlock *block)
}
if(pass==0) {
- /* Skip to next delimeter on first pass (be picky) */
+ /* Skip to next delimiter on first pass (be picky) */
while(isalpha(*str_pt))
str_pt++;
@@ -1878,7 +1878,7 @@ static double soft_range_round_down(double value, double max)
void ui_set_but_soft_range(uiBut *but, double value)
{
- /* ideally we would not limit this but practially, its more then
+ /* ideally we would not limit this but practically, its more then
* enough worst case is very long vectors wont use a smart soft-range
* which isnt so bad. */
diff --git a/source/blender/editors/interface/interface_handlers.c b/source/blender/editors/interface/interface_handlers.c
index b7c250743a9..fbc196467aa 100644
--- a/source/blender/editors/interface/interface_handlers.c
+++ b/source/blender/editors/interface/interface_handlers.c
@@ -2888,7 +2888,7 @@ static int ui_do_but_BLOCK(bContext *C, uiBut *but, uiHandleButtonData *data, wm
* to cancel changes made to this button, but changing state to EXIT also makes no button active for
* a while which leads to triggering operator when doing fast scrolling mouse wheel.
* using post activate stuff from button allows to make button be active again after checking for all
- * all that mouse leave and cancel stuff, so quick scroll wouldnt't be an issue anymore.
+ * all that mouse leave and cancel stuff, so quick scroll wouldn't be an issue anymore.
* same goes for scrolling wheel in another direction below (sergey)
*/
data->postbut= but;
@@ -2963,7 +2963,7 @@ static int ui_numedit_but_NORMAL(uiBut *but, uiHandleButtonData *data, int mx, i
/* if mouse moves outside of sphere, it does negative normal */
/* note that both data->vec and data->origvec should be normalized
- * else we'll get a hamrless but annoying jump when first clicking */
+ * else we'll get a harmless but annoying jump when first clicking */
fp= data->origvec;
rad= (but->x2 - but->x1);
diff --git a/source/blender/editors/interface/interface_regions.c b/source/blender/editors/interface/interface_regions.c
index 40bd332a056..f971410672c 100644
--- a/source/blender/editors/interface/interface_regions.c
+++ b/source/blender/editors/interface/interface_regions.c
@@ -1755,11 +1755,11 @@ void ui_block_func_ICONTEXTROW(bContext *UNUSED(C), uiLayout *layout, void *arg_
static void ui_warp_pointer(int x, int y)
{
/* XXX 2.50 which function to use for this? */
- /* OSX has very poor mousewarp support, it sends events;
+ /* OSX has very poor mouse-warp support, it sends events;
* this causes a menu being pressed immediately ... */
- #ifndef __APPLE__
+# ifndef __APPLE__
warp_pointer(x, y);
- #endif
+# endif
}
#endif
diff --git a/source/blender/editors/interface/view2d.c b/source/blender/editors/interface/view2d.c
index e539c02ee17..2feccf7a4e8 100644
--- a/source/blender/editors/interface/view2d.c
+++ b/source/blender/editors/interface/view2d.c
@@ -1105,7 +1105,7 @@ static void step_to_grid(float *step, int *power, int unit)
}
}
-/* Intialise settings necessary for drawing gridlines in a 2d-view
+/* Initialize settings necessary for drawing gridlines in a 2d-view
* - Currently, will return pointer to View2DGrid struct that needs to
* be freed with UI_view2d_grid_free()
* - Is used for scrollbar drawing too (for units drawing)
diff --git a/source/blender/editors/mesh/editmesh_bvh.c b/source/blender/editors/mesh/editmesh_bvh.c
index d9ba7a1b36a..44d4d554ac8 100644
--- a/source/blender/editors/mesh/editmesh_bvh.c
+++ b/source/blender/editors/mesh/editmesh_bvh.c
@@ -87,7 +87,7 @@ BMBVHTree *BMBVH_NewBVH(BMEditMesh *em, int flag, Scene *scene, Object *obedit)
int i;
/* when initializing cage verts, we only want the first cage coordinate for each vertex,
- * so that e.g. mirror or array use original vertex coordiantes and not mirrored or duplicate */
+ * so that e.g. mirror or array use original vertex coordinates and not mirrored or duplicate */
BLI_smallhash_init(&shash);
BMEdit_RecalcTessellation(em);
diff --git a/source/blender/editors/object/object_constraint.c b/source/blender/editors/object/object_constraint.c
index b7b2033b2ed..774eec0e0a8 100644
--- a/source/blender/editors/object/object_constraint.c
+++ b/source/blender/editors/object/object_constraint.c
@@ -1500,7 +1500,7 @@ static int constraint_add_exec(bContext *C, wmOperator *op, Object *ob, ListBase
/* get the target objects, adding them as need be */
if (get_new_constraint_target(C, type, &tar_ob, &tar_pchan, 1)) {
/* method of setting target depends on the type of target we've got
- * - by default, just set the first target (distinction here is only for multiple-targetted constraints)
+ * - by default, just set the first target (distinction here is only for multiple-targeted constraints)
*/
if (tar_pchan)
set_constraint_nth_target(con, tar_ob, tar_pchan->name, 0);
diff --git a/source/blender/editors/physics/dynamicpaint_ops.c b/source/blender/editors/physics/dynamicpaint_ops.c
index b6584122f3a..abb596e450f 100644
--- a/source/blender/editors/physics/dynamicpaint_ops.c
+++ b/source/blender/editors/physics/dynamicpaint_ops.c
@@ -396,7 +396,7 @@ static int dynamicPaint_initBake(struct bContext *C, struct wmOperator *op)
BLI_snprintf(result_str, sizeof(result_str), "Bake Failed: %s", canvas->error);
BKE_report(op->reports, RPT_ERROR, result_str);
}
- else { /* User cancelled the bake */
+ else { /* User canceled the bake */
BLI_strncpy(result_str, "Baking Cancelled!", sizeof(result_str));
BKE_report(op->reports, RPT_WARNING, result_str);
}
diff --git a/source/blender/editors/screen/screen_edit.c b/source/blender/editors/screen/screen_edit.c
index 24a8de6688e..7be09b1d5f3 100644
--- a/source/blender/editors/screen/screen_edit.c
+++ b/source/blender/editors/screen/screen_edit.c
@@ -649,7 +649,7 @@ static void screen_test_scale(bScreen *sc, int winsizex, int winsizey)
/* make sure it fits! */
for(sv= sc->vertbase.first; sv; sv= sv->next) {
- /* FIXME, this resizing logic is no good when resizing the window + redrawing [#24428]
+ /* FIXME, this re-sizing logic is no good when re-sizing the window + redrawing [#24428]
* need some way to store these as floats internally and re-apply from there. */
tempf= ((float)sv->vec.x)*facx;
sv->vec.x= (short)(tempf+0.5f);
diff --git a/source/blender/editors/sculpt_paint/paint_image.c b/source/blender/editors/sculpt_paint/paint_image.c
index 2d208eea00a..32dda420aec 100644
--- a/source/blender/editors/sculpt_paint/paint_image.c
+++ b/source/blender/editors/sculpt_paint/paint_image.c
@@ -2601,7 +2601,7 @@ static void project_paint_face_init(const ProjPaintState *ps, const int thread_i
/* We need to find the closest point along the face edge,
* getting the screen_px_from_*** wont work because our actual location
- * is not relevent, since we are outside the face, Use VecLerpf to find
+ * is not relevant, since we are outside the face, Use VecLerpf to find
* our location on the side of the face's UV */
#if 0
if (is_ortho) screen_px_from_ortho(ps, uv, v1co, v2co, v3co, uv1co, uv2co, uv3co, pixelScreenCo);
@@ -3053,7 +3053,7 @@ static void project_paint_begin(ProjPaintState *ps)
ps->is_ortho= project_paint_view_clip(ps->v3d, ps->rv3d, &ps->clipsta, &ps->clipend);
}
else {
- /* reprojection */
+ /* re-projection */
float winmat[4][4];
float vmat[4][4];
@@ -3178,7 +3178,7 @@ static void project_paint_begin(ProjPaintState *ps)
CLAMP(ps->screenMax[1], (float)(-diameter), (float)(ps->winy + diameter));
#endif
}
- else { /* reprojection, use bounds */
+ else { /* re-projection, use bounds */
ps->screenMin[0]= 0;
ps->screenMax[0]= (float)(ps->winx);
@@ -5751,7 +5751,7 @@ static int texture_paint_image_from_view_exec(bContext *C, wmOperator *op)
if(image) {
/* now for the trickyness. store the view projection here!
- * reprojection will reuse this */
+ * re-projection will reuse this */
View3D *v3d= CTX_wm_view3d(C);
RegionView3D *rv3d= CTX_wm_region_view3d(C);
diff --git a/source/blender/editors/sculpt_paint/sculpt.c b/source/blender/editors/sculpt_paint/sculpt.c
index ec0064df13b..c7b27742969 100644
--- a/source/blender/editors/sculpt_paint/sculpt.c
+++ b/source/blender/editors/sculpt_paint/sculpt.c
@@ -653,7 +653,7 @@ static float tex_strength(SculptSession *ss, Brush *br, float point[3],
float radius;
/* if the active area is being applied for symmetry, flip it
- * across the symmetry axis and rotate it back to the orignal
+ * across the symmetry axis and rotate it back to the original
* position in order to project it. This insures that the
* brush texture will be oriented correctly. */
diff --git a/source/blender/editors/space_action/space_action.c b/source/blender/editors/space_action/space_action.c
index 4baaa469127..7bda0c9a510 100644
--- a/source/blender/editors/space_action/space_action.c
+++ b/source/blender/editors/space_action/space_action.c
@@ -458,7 +458,7 @@ static void action_refresh(const bContext *C, ScrArea *sa)
}
/* region updates? */
- // XXX resizing y-extents of tot should go here?
+ // XXX re-sizing y-extents of tot should go here?
}
/* only called once, from space/spacetypes.c */
diff --git a/source/blender/editors/space_clip/clip_draw.c b/source/blender/editors/space_clip/clip_draw.c
index e99d5919cd4..920b8dc3ccb 100644
--- a/source/blender/editors/space_clip/clip_draw.c
+++ b/source/blender/editors/space_clip/clip_draw.c
@@ -686,7 +686,7 @@ static void draw_marker_slide_zones(SpaceClip *sc, MovieTrackingTrack *track, Mo
glVertex3f(x-tdx, y-tdy, 0);
glEnd();
- /* search resizing triangle */
+ /* search re-sizing triangle */
x= track->search_max[0];
y= track->search_min[1];
@@ -730,7 +730,7 @@ static void draw_marker_slide_zones(SpaceClip *sc, MovieTrackingTrack *track, Mo
glVertex3f(x-tdx, y-tdy, 0);
glEnd();
- /* pattern resizing triangle */
+ /* pattern re-sizing triangle */
x= track->pat_max[0];
y= track->pat_min[1];
diff --git a/source/blender/editors/space_clip/space_clip.c b/source/blender/editors/space_clip/space_clip.c
index 3a5b7009a20..3e0168fa071 100644
--- a/source/blender/editors/space_clip/space_clip.c
+++ b/source/blender/editors/space_clip/space_clip.c
@@ -732,7 +732,7 @@ static void clip_main_area_draw(const bContext *C, ARegion *ar)
Scene *scene= CTX_data_scene(C);
MovieClip *clip= ED_space_clip(sc);
- /* if tracking is in progress, we should sunchronize framenr from clipuser
+ /* if tracking is in progress, we should synchronize framenr from clipuser
* so latest tracked frame would be shown */
if(clip && clip->tracking_context)
BKE_tracking_sync_user(&sc->user, clip->tracking_context);
diff --git a/source/blender/editors/space_clip/tracking_ops.c b/source/blender/editors/space_clip/tracking_ops.c
index 68b98ce756c..05a84f04cd4 100644
--- a/source/blender/editors/space_clip/tracking_ops.c
+++ b/source/blender/editors/space_clip/tracking_ops.c
@@ -1493,7 +1493,7 @@ static int track_markers_invoke(bContext *C, wmOperator *op, wmEvent *UNUSED(eve
WM_jobs_customdata(steve, tmj, track_markers_freejob);
/* if there's delay set in tracking job, tracking should happen
- * with fixed FPS. To deal with editor refresh we have to syncronize
+ * with fixed FPS. To deal with editor refresh we have to synchronize
* tracks from job and tracks in clip. Do this in timer callback
* to prevent threading conflicts. */
if(tmj->delay>0) WM_jobs_timer(steve, tmj->delay/1000.0f, NC_MOVIECLIP|NA_EVALUATED, 0);
@@ -1627,7 +1627,7 @@ static void solve_camera_freejob(void *scv)
if(!solved)
BKE_report(scj->reports, RPT_WARNING, "Some data failed to reconstruct, see console for details");
else
- BKE_reportf(scj->reports, RPT_INFO, "Average reprojection error %.3f", tracking->reconstruction.error);
+ BKE_reportf(scj->reports, RPT_INFO, "Average re-projection error %.3f", tracking->reconstruction.error);
/* set currently solved clip as active for scene */
if(scene->clip)
@@ -3472,7 +3472,7 @@ void CLIP_OT_clean_tracks(wmOperatorType *ot)
/* properties */
RNA_def_int(ot->srna, "frames", 0, 0, INT_MAX, "Tracked Frames", "Effect on tracks which are tracked less than specified amount of frames", 0, INT_MAX);
- RNA_def_float(ot->srna, "error", 0.0f, 0.0f, FLT_MAX, "Reprojection Error", "Effect on tracks with have got larger reprojection error", 0.0f, 100.0f);
+ RNA_def_float(ot->srna, "error", 0.0f, 0.0f, FLT_MAX, "Reprojection Error", "Effect on tracks with have got larger re-projection error", 0.0f, 100.0f);
RNA_def_enum(ot->srna, "action", actions_items, 0, "Action", "Cleanup action to execute");
}
diff --git a/source/blender/editors/space_console/space_console.c b/source/blender/editors/space_console/space_console.c
index 701a0bb1cb8..d781179249b 100644
--- a/source/blender/editors/space_console/space_console.c
+++ b/source/blender/editors/space_console/space_console.c
@@ -136,7 +136,7 @@ static void console_main_area_init(wmWindowManager *wm, ARegion *ar)
wmKeyMap *keymap;
ListBase *lb;
- const float prev_y_min= ar->v2d.cur.ymin; /* so resizing keeps the cursor visible */
+ const float prev_y_min= ar->v2d.cur.ymin; /* so re-sizing keeps the cursor visible */
UI_view2d_region_reinit(&ar->v2d, V2D_COMMONVIEW_CUSTOM, ar->winx, ar->winy);
diff --git a/source/blender/editors/space_graph/space_graph.c b/source/blender/editors/space_graph/space_graph.c
index 50178f73d89..08f21a3f5aa 100644
--- a/source/blender/editors/space_graph/space_graph.c
+++ b/source/blender/editors/space_graph/space_graph.c
@@ -508,7 +508,7 @@ static void graph_refresh(const bContext *C, ScrArea *sa)
}
/* region updates? */
- // XXX resizing y-extents of tot should go here?
+ // XXX re-sizing y-extents of tot should go here?
/* update the state of the animchannels in response to changes from the data they represent
* NOTE: the temp flag is used to indicate when this needs to be done, and will be cleared once handled
diff --git a/source/blender/editors/space_text/text_draw.c b/source/blender/editors/space_text/text_draw.c
index a6bc0d9612a..e9062b052e6 100644
--- a/source/blender/editors/space_text/text_draw.c
+++ b/source/blender/editors/space_text/text_draw.c
@@ -959,7 +959,7 @@ void text_drawcache_tag_update(SpaceText *st, int full)
}
/* quick cache recalculation is also used in delete operator,
- * which could merge lines which are adjusent to current selection lines
+ * which could merge lines which are adjacent to current selection lines
* expand recalculate area to this lines */
if(drawcache->valid_head>0) drawcache->valid_head--;
if(drawcache->valid_tail>0) drawcache->valid_tail--;
@@ -1113,7 +1113,7 @@ static void calc_text_rcts(SpaceText *st, ARegion *ar, rcti *scroll, rcti *back)
scroll->ymin= 4;
scroll->ymax= 4+pix_available;
- /* when resizing a view-port with the bar at the bottom to a greater height more blank lines will be added */
+ /* when re-sizing a view-port with the bar at the bottom to a greater height more blank lines will be added */
if(ltexth + blank_lines < st->top + st->viewlines) {
blank_lines = st->top + st->viewlines - ltexth;
}
diff --git a/source/blender/editors/space_view3d/drawobject.c b/source/blender/editors/space_view3d/drawobject.c
index e56b4216583..73e7bbc6e90 100644
--- a/source/blender/editors/space_view3d/drawobject.c
+++ b/source/blender/editors/space_view3d/drawobject.c
@@ -2819,7 +2819,7 @@ static void draw_em_measure_stats(View3D *v3d, Object *ob, BMEditMesh *em, UnitS
if (me->drawflag & ME_DRAWEXTRA_FACEAREA) {
/* would be nice to use BM_face_area_calc, but that is for 2d faces
- * so instead add up tessellationf triangle areas */
+ * so instead add up tessellation triangle areas */
BMFace *f;
int n;
@@ -3451,7 +3451,7 @@ static void draw_mesh_fancy(Scene *scene, ARegion *ar, View3D *v3d, RegionView3D
}
if (draw_wire != OBDRAW_WIRE_OFF) {
- /* When using wireframe object traw in particle edit mode
+ /* When using wireframe object draw in particle edit mode
* the mesh gets in the way of seeing the particles, fade the wire color
* with the background. */
if (is_obact && (ob->mode & OB_MODE_PARTICLE_EDIT)) {
diff --git a/source/blender/editors/transform/transform_constraints.c b/source/blender/editors/transform/transform_constraints.c
index dfe582412b6..017501bd78e 100644
--- a/source/blender/editors/transform/transform_constraints.c
+++ b/source/blender/editors/transform/transform_constraints.c
@@ -890,7 +890,7 @@ static void setNearestAxis3d(TransInfo *t)
/* we need to correct axis length for the current zoomlevel of view,
* this to prevent projected values to be clipped behind the camera
* and to overflow the short integers.
- * The formula used is a bit stupid, just a simplification of the substraction
+ * The formula used is a bit stupid, just a simplification of the subtraction
* of two 2D points 30 pixels apart (that's the last factor in the formula) after
* projecting them with window_to_3d_delta and then get the length of that vector.
*/
diff --git a/source/blender/editors/transform/transform_generics.c b/source/blender/editors/transform/transform_generics.c
index b32ed17f57a..f59b075525e 100644
--- a/source/blender/editors/transform/transform_generics.c
+++ b/source/blender/editors/transform/transform_generics.c
@@ -469,7 +469,7 @@ static void recalcData_nla(TransInfo *t)
if ((snla->flag & SNLA_NOREALTIMEUPDATES) == 0)
ANIM_id_update(t->scene, tdn->id);
- /* if cancelling transform, just write the values without validating, then move on */
+ /* if canceling transform, just write the values without validating, then move on */
if (t->state == TRANS_CANCEL) {
/* clear the values by directly overwriting the originals, but also need to restore
* endpoints of neighboring transition-strips
diff --git a/source/blender/makesdna/DNA_customdata_types.h b/source/blender/makesdna/DNA_customdata_types.h
index d7358a4df1e..2a8c4c3a74e 100644
--- a/source/blender/makesdna/DNA_customdata_types.h
+++ b/source/blender/makesdna/DNA_customdata_types.h
@@ -59,7 +59,7 @@ typedef struct CustomDataExternal {
} CustomDataExternal;
/** structure which stores custom element data associated with mesh elements
- * (vertices, edges or faces). The custom data is organised into a series of
+ * (vertices, edges or faces). The custom data is organized into a series of
* layers, each with a data type (e.g. MTFace, MDeformVert, etc.). */
typedef struct CustomData {
CustomDataLayer *layers; /* CustomDataLayers, ordered by type */
diff --git a/source/blender/makesdna/DNA_userdef_types.h b/source/blender/makesdna/DNA_userdef_types.h
index d64c3133001..e72b7dcfa72 100644
--- a/source/blender/makesdna/DNA_userdef_types.h
+++ b/source/blender/makesdna/DNA_userdef_types.h
@@ -617,7 +617,7 @@ extern UserDef U; /* from blenkernel blender.c */
#define NDOF_SHOULD_ZOOM (1 << 4)
#define NDOF_SHOULD_ROTATE (1 << 5)
/* orbit navigation modes
- * only two options, so it's sort of a hyrbrid bool/enum
+ * only two options, so it's sort of a hybrid bool/enum
* if ((U.ndof_flag & NDOF_ORBIT_MODE) == NDOF_OM_OBJECT)... */
/*
#define NDOF_ORBIT_MODE (1 << 6)
diff --git a/source/blender/makesrna/intern/rna_tracking.c b/source/blender/makesrna/intern/rna_tracking.c
index 83c4b235d20..d2385daa526 100644
--- a/source/blender/makesrna/intern/rna_tracking.c
+++ b/source/blender/makesrna/intern/rna_tracking.c
@@ -578,12 +578,12 @@ static void rna_def_trackingSettings(BlenderRNA *brna)
RNA_def_property_range(prop, 0, INT_MAX);
RNA_def_property_ui_text(prop, "Tracked Frames", "Effect on tracks which are tracked less than the specified amount of frames");
- /* reprojection error */
+ /* re-projection error */
prop = RNA_def_property(srna, "clean_error", PROP_FLOAT, PROP_NONE);
RNA_def_property_clear_flag(prop, PROP_ANIMATABLE);
RNA_def_property_float_sdna(prop, NULL, "clean_error");
RNA_def_property_range(prop, 0, FLT_MAX);
- RNA_def_property_ui_text(prop, "Reprojection Error", "Effect on tracks which have a larger reprojection error");
+ RNA_def_property_ui_text(prop, "Reprojection Error", "Effect on tracks which have a larger re-projection error");
/* cleanup action */
prop = RNA_def_property(srna, "clean_action", PROP_ENUM, PROP_NONE);
diff --git a/source/blender/makesrna/intern/rna_wm_api.c b/source/blender/makesrna/intern/rna_wm_api.c
index 131cc39933f..bfe0f1cba65 100644
--- a/source/blender/makesrna/intern/rna_wm_api.c
+++ b/source/blender/makesrna/intern/rna_wm_api.c
@@ -324,7 +324,7 @@ void RNA_api_operator(StructRNA *srna)
/* cancel */
func = RNA_def_function(srna, "cancel", NULL);
- RNA_def_function_ui_description(func, "Called when the operator is cancelled");
+ RNA_def_function_ui_description(func, "Called when the operator is canceled");
RNA_def_function_flag(func, FUNC_REGISTER_OPTIONAL);
parm = RNA_def_pointer(func, "context", "Context", "", "");
RNA_def_property_flag(parm, PROP_REQUIRED|PROP_NEVER_NULL);
diff --git a/source/blender/modifiers/intern/MOD_mirror.c b/source/blender/modifiers/intern/MOD_mirror.c
index 6552ff38645..51e65e2387a 100644
--- a/source/blender/modifiers/intern/MOD_mirror.c
+++ b/source/blender/modifiers/intern/MOD_mirror.c
@@ -128,7 +128,7 @@ static DerivedMesh *doMirrorOnAxis(MirrorModifierData *mmd,
invert_m4_m4(tmp, mmd->mirror_ob->obmat);
mult_m4_m4m4(tmp, tmp, ob->obmat);
- /* itmp is the reverse transform back to origin-relative coordiantes */
+ /* itmp is the reverse transform back to origin-relative coordinates */
invert_m4_m4(itmp, tmp);
/* combine matrices to get a single matrix that translates coordinates into
diff --git a/source/blender/python/intern/bpy_rna.c b/source/blender/python/intern/bpy_rna.c
index 5fbfb75555f..ba07070e64b 100644
--- a/source/blender/python/intern/bpy_rna.c
+++ b/source/blender/python/intern/bpy_rna.c
@@ -2621,7 +2621,7 @@ static int prop_subscript_ass_array_slice(PointerRNA *ptr, PropertyRNA *prop,
if (PySequence_Fast_GET_SIZE(value) != stop-start) {
Py_DECREF(value);
PyErr_SetString(PyExc_TypeError,
- "bpy_prop_array[slice] = value: resizing bpy_struct arrays isn't supported");
+ "bpy_prop_array[slice] = value: re-sizing bpy_struct arrays isn't supported");
return -1;
}
diff --git a/source/blender/windowmanager/WM_types.h b/source/blender/windowmanager/WM_types.h
index 3a62faeab8a..3a0e5eab143 100644
--- a/source/blender/windowmanager/WM_types.h
+++ b/source/blender/windowmanager/WM_types.h
@@ -448,7 +448,7 @@ typedef struct wmOperatorType {
/* for modal temporary operators, initially invoke is called. then
* any further events are handled in modal. if the operation is
- * cancelled due to some external reason, cancel is called
+ * canceled due to some external reason, cancel is called
* - see defines below for return values */
int (*invoke)(struct bContext *, struct wmOperator *, struct wmEvent *);
int (*cancel)(struct bContext *, struct wmOperator *);
diff --git a/source/blender/windowmanager/intern/wm_event_system.c b/source/blender/windowmanager/intern/wm_event_system.c
index 1d2252b7ceb..7bc0557b631 100644
--- a/source/blender/windowmanager/intern/wm_event_system.c
+++ b/source/blender/windowmanager/intern/wm_event_system.c
@@ -1365,7 +1365,7 @@ static int wm_handler_operator_call(bContext *C, ListBase *handlers, wmEventHand
handler->op= NULL;
}
- /* remove modal handler, operator itself should have been cancelled and freed */
+ /* remove modal handler, operator itself should have been canceled and freed */
if(retval & (OPERATOR_CANCELLED|OPERATOR_FINISHED)) {
WM_cursor_ungrab(CTX_wm_window(C));
@@ -2337,7 +2337,7 @@ void WM_event_add_mousemove(bContext *C)
int WM_modal_tweak_exit(wmEvent *evt, int tweak_event)
{
/* if the release-confirm userpref setting is enabled,
- * tweak events can be cancelled when mouse is released
+ * tweak events can be canceled when mouse is released
*/
if (U.flag & USER_RELEASECONFIRM) {
/* option on, so can exit with km-release */
diff --git a/source/blender/windowmanager/intern/wm_operators.c b/source/blender/windowmanager/intern/wm_operators.c
index f9cbfc88301..290046d59ab 100644
--- a/source/blender/windowmanager/intern/wm_operators.c
+++ b/source/blender/windowmanager/intern/wm_operators.c
@@ -3387,7 +3387,7 @@ static int radial_control_modal(bContext *C, wmOperator *op, wmEvent *event)
case ESCKEY:
case RIGHTMOUSE:
- /* cancelled; restore original value */
+ /* canceled; restore original value */
radial_control_set_value(rc, rc->initial_value);
ret = OPERATOR_CANCELLED;
break;
diff --git a/source/creator/creator.c b/source/creator/creator.c
index 764e6dbec63..7b67cdad23c 100644
--- a/source/creator/creator.c
+++ b/source/creator/creator.c
@@ -649,7 +649,7 @@ static int set_ge_parameters(int argc, const char **argv, void *data)
#endif
/**
- * gameengine parameters are automaticly put into system
+ * gameengine parameters are automatically put into system
* -g [paramname = value]
* -g [boolparamname]
* example:
diff --git a/source/blender/editors/transform/transform_conversions.c b/source/blender/editors/transform/transform_conversions.c
index fa0575ca9db..be2382fd11c 100644
--- a/source/blender/editors/transform/transform_conversions.c
+++ b/source/blender/editors/transform/transform_conversions.c
@@ -4859,7 +4859,7 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
{
Object *ob;
// short redrawipo=0, resetslowpar=1;
- int cancelled= (t->state == TRANS_CANCEL);
+ int canceled= (t->state == TRANS_CANCEL);
short duplicate= (t->mode == TFM_TIME_DUPLICATE);
/* early out when nothing happened */
@@ -4868,12 +4868,12 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
if (t->spacetype==SPACE_VIEW3D) {
if (t->obedit) {
- if (cancelled==0) {
+ if (canceled==0) {
/* we need to delete the temporary faces before automerging */
if(t->mode == TFM_EDGE_SLIDE){
SlideData *sld = t->customData;
- /* handle multires reprojection, done
+ /* handle multires re-projection, done
* on transform completion since it's
* really slow -joeedh */
projectSVData(t, TRUE);
@@ -4908,7 +4908,7 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* marker transform, not especially nice but we may want to move markers
* at the same time as keyframes in the dope sheet. */
- if ((sseq->flag & SEQ_MARKER_TRANS) && (cancelled == 0)) {
+ if ((sseq->flag & SEQ_MARKER_TRANS) && (canceled == 0)) {
/* cant use , TFM_TIME_EXTEND
* for some reason EXTEND is changed into TRANSLATE, so use frame_side instead */
@@ -4926,7 +4926,7 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
SpaceNode *snode= (SpaceNode *)t->sa->spacedata.first;
ED_node_update_hierarchy(C, snode->edittree);
- if(cancelled == 0)
+ if(canceled == 0)
ED_node_link_insert(t->sa);
/* clear link line */
@@ -4968,11 +4968,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* 3 cases here for curve cleanups:
* 1) NOTRANSKEYCULL on -> cleanup of duplicates shouldn't be done
* 2) cancelled == 0 -> user confirmed the transform, so duplicates should be removed
* 3) cancelled + duplicate -> user cancelled the transform, but we made duplicates, so get rid of these
*/
if ( (saction->flag & SACTION_NOTRANSKEYCULL)==0 &&
- ((cancelled == 0) || (duplicate)) )
+ ((canceled == 0) || (duplicate)) )
{
if (adt) {
ANIM_nla_mapping_apply_fcurve(adt, fcu, 0, 1);
@@ -4999,11 +4999,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* 3 cases here for curve cleanups:
* 1) NOTRANSKEYCULL on -> cleanup of duplicates shouldn't be done
* 2) cancelled == 0 -> user confirmed the transform, so duplicates should be removed
* 3) cancelled + duplicate -> user cancelled the transform, but we made duplicates, so get rid of these
*/
if ( (saction->flag & SACTION_NOTRANSKEYCULL)==0 &&
- ((cancelled == 0) || (duplicate)) )
+ ((canceled == 0) || (duplicate)) )
{
posttrans_action_clean(&ac, (bAction *)ac.data);
}
@@ -5012,11 +5012,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* remove duplicate frames and also make sure points are in order! */
/* 3 cases here for curve cleanups:
* 1) NOTRANSKEYCULL on -> cleanup of duplicates shouldn't be done
* 2) cancelled == 0 -> user confirmed the transform, so duplicates should be removed
* 3) cancelled + duplicate -> user cancelled the transform, but we made duplicates, so get rid of these
*/
if ( (saction->flag & SACTION_NOTRANSKEYCULL)==0 &&
- ((cancelled == 0) || (duplicate)) )
+ ((canceled == 0) || (duplicate)) )
{
bGPdata *gpd;
@@ -5032,7 +5032,7 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* marker transform, not especially nice but we may want to move markers
* at the same time as keyframes in the dope sheet.
*/
- if ((saction->flag & SACTION_MARKERS_MOVE) && (cancelled == 0)) {
+ if ((saction->flag & SACTION_MARKERS_MOVE) && (canceled == 0)) {
if (t->mode == TFM_TIME_TRANSLATE) {
#if 0
if (ELEM(t->frame_side, 'L', 'R')) { /* TFM_TIME_EXTEND */
@@ -5081,11 +5081,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* 3 cases here for curve cleanups:
* 1) NOTRANSKEYCULL on -> cleanup of duplicates shouldn't be done
* 2) cancelled == 0 -> user confirmed the transform, so duplicates should be removed
* 3) cancelled + duplicate -> user cancelled the transform, but we made duplicates, so get rid of these
*/
if ( (sipo->flag & SIPO_NOTRANSKEYCULL)==0 &&
- ((cancelled == 0) || (duplicate)) )
+ ((canceled == 0) || (duplicate)) )
{
if (adt) {
ANIM_nla_mapping_apply_fcurve(adt, fcu, 0, 0);
@@ -5106,7 +5106,7 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
* Note: if the refresh is really needed after cancel then some way
* has to be added to not update handle types (see bug 22289).
*/
- if(!cancelled)
+ if(!canceled)
ANIM_editkeyframes_refresh(&ac);
}
else if (t->spacetype == SPACE_NLA) {
@@ -5167,11 +5167,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
}
/* set BONE_TRANSFORM flags for autokey, manipulator draw might have changed them */
- if (!cancelled && (t->mode != TFM_DUMMY))
+ if (!canceled && (t->mode != TFM_DUMMY))
count_set_pose_transflags(&t->mode, t->around, ob);
/* if target-less IK grabbing, we calculate the pchan transforms and clear flag */
- if (!cancelled && t->mode==TFM_TRANSLATION)
+ if (!canceled && t->mode==TFM_TRANSLATION)
targetless_ik= apply_targetless_ik(ob);
else {
/* not forget to clear the auto flag */
@@ -5184,8 +5184,8 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
if (t->mode==TFM_TRANSLATION)
pose_grab_with_ik_clear(ob);
- /* automatic inserting of keys and unkeyed tagging - only if transform wasn't cancelled (or TFM_DUMMY) */
- if (!cancelled && (t->mode != TFM_DUMMY)) {
+ /* automatic inserting of keys and unkeyed tagging - only if transform wasn't canceled (or TFM_DUMMY) */
+ if (!canceled && (t->mode != TFM_DUMMY)) {
autokeyframe_pose_cb_func(C, t->scene, (View3D *)t->view, ob, t->mode, targetless_ik);
DAG_id_tag_update(&ob->id, OB_RECALC_DATA);
}
@@ -5239,7 +5239,7 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
DAG_id_tag_update(&ob->id, OB_RECALC_OB);
/* Set autokey if necessary */
- if (!cancelled) {
+ if (!canceled) {
autokeyframe_ob_cb_func(C, t->scene, (View3D *)t->view, ob, t->mode);
/* only calculate paths if there are paths to be recalculated */
@@ -4968,11 +4968,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* 3 cases here for curve cleanups:
* 1) NOTRANSKEYCULL on -> cleanup of duplicates shouldn't be done
- * 2) cancelled == 0 -> user confirmed the transform, so duplicates should be removed
- * 3) cancelled + duplicate -> user cancelled the transform, but we made duplicates, so get rid of these
+ * 2) canceled == 0 -> user confirmed the transform, so duplicates should be removed
+ * 3) canceled + duplicate -> user canceled the transform, but we made duplicates, so get rid of these
*/
if ( (saction->flag & SACTION_NOTRANSKEYCULL)==0 &&
@@ -4999,11 +4999,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* 3 cases here for curve cleanups:
* 1) NOTRANSKEYCULL on -> cleanup of duplicates shouldn't be done
- * 2) cancelled == 0 -> user confirmed the transform, so duplicates should be removed
- * 3) cancelled + duplicate -> user cancelled the transform, but we made duplicates, so get rid of these
+ * 2) canceled == 0 -> user confirmed the transform, so duplicates should be removed
+ * 3) canceled + duplicate -> user canceled the transform, but we made duplicates, so get rid of these
*/
if ( (saction->flag & SACTION_NOTRANSKEYCULL)==0 &&
@@ -5012,11 +5012,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* 3 cases here for curve cleanups:
* 1) NOTRANSKEYCULL on -> cleanup of duplicates shouldn't be done
- * 2) cancelled == 0 -> user confirmed the transform, so duplicates should be removed
- * 3) cancelled + duplicate -> user cancelled the transform, but we made duplicates, so get rid of these
+ * 2) canceled == 0 -> user confirmed the transform, so duplicates should be removed
+ * 3) canceled + duplicate -> user canceled the transform, but we made duplicates, so get rid of these
*/
if ( (saction->flag & SACTION_NOTRANSKEYCULL)==0 &&
@@ -5081,11 +5081,11 @@ void special_aftertrans_update(bContext *C, TransInfo *t)
/* 3 cases here for curve cleanups:
* 1) NOTRANSKEYCULL on -> cleanup of duplicates shouldn't be done
- * 2) cancelled == 0 -> user confirmed the transform, so duplicates should be removed
- * 3) cancelled + duplicate -> user cancelled the transform, but we made duplicates, so get rid of these
+ * 2) canceled == 0 -> user confirmed the transform, so duplicates should be removed
+ * 3) canceled + duplicate -> user canceled the transform, but we made duplicates, so get rid of these
*/
if ( (sipo->flag & SIPO_NOTRANSKEYCULL)==0 &&